@@ -245,11 +245,12 @@ class S3:
 			n_and_e = self.get_file_name_and_extension(path=path).lower()
 			return n_and_e.startswith('part-') and n_and_e.endswith('.parquet')
 
-	def load_parquet(self, path, spark=None):
+	def load_parquet(self, path, spark=None, parallel=True):
 		"""
 		reads parquet files inside a path and returns the data
 		:type path: str
 		:type spark: SparkSession or NoneType
+		:type parallel: bool
 		:rtype: DataFrame
 		"""
 		if spark is None:
@@ -265,14 +266,17 @@ class S3:
 			else:
 				raise FileNotFoundError(f'"{file}" is empty!')
 
-		parquet_files = [file for file in files if self.is_parquet_file(path=file)]
+		elif parallel:
+			return spark.read.load(path=f'{path}/part-*.parquet')
 
-		result = None
-		for parquet in parquet_files:
-			data = spark.read.load(self._get_absolute_path(parquet))
-			if result is None:
-				result = data
-			else:
-				result = result.union(data)
+		else:
+			parquet_files = [file for file in files if self.is_parquet_file(path=file)]
+			result = None
+			for parquet in parquet_files:
+				data = spark.read.load(self._get_absolute_path(parquet))
+				if result is None:
+					result = data
+				else:
+					result = result.union(data)
 
-		return result
+			return result
